@@ -1,5 +1,3 @@
-#' @export zero.pad
-#' 
 #' @title Zero Pad Integers
 #' 
 #' @param x a vector of integers.
@@ -11,9 +9,11 @@
 #' zero.pad(x)
 #' x <- c(x, 11, 12, 100, 1000)
 #' zero.pad(x)
-
+#' 
+#' @export
+#' 
 zero.pad <- function(x) {
   is.whole <- abs(x - round(x)) < .Machine$double.eps ^ 0.5
   if(!all(is.whole)) stop("'x' must be a vector of integers")
-  formatC(x, digits = floor(log10(max(x))), flag = "0")
+  formatC(x, digits = floor(log10(max(x))), flag = "0", mode = "integer")
 }
\ No newline at end of file
